@@ -4,6 +4,7 @@ package KiokuDB::Backend;
 use Moose::Role;
 
 use Moose::Util::TypeConstraints;
+use Try::Tiny;
 
 use namespace::clean -except => 'meta';
 
@@ -12,16 +13,13 @@ coerce ( __PACKAGE__,
         my %p = %$_;
         my $class = delete $p{class} || die "Can't coerce backend from hash without a 'class' parameter";
 
-        do {
-            local $@;
-            eval {
-                Class::MOP::load_class("KiokuDB::Backend::$class");
-                "KiokuDB::Backend::$class"->new(%p);
-            }
-        } or do {
+        try {
+            Class::MOP::load_class("KiokuDB::Backend::$class");
+            "KiokuDB::Backend::$class"->new(%p);
+        } catch {
             Class::MOP::load_class($class);
             $class->new(%p);
-        }
+        };
     },
 );
 
